==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTextUI__24RootView.h <==
// class javax.swing.plaf.basic.BasicTextUI$RootView

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3c149a3a98797f6b javax_swing_plaf_basic_BasicTextUI__24RootView
// @dep_class b564f56d2f2041c1 javax_swing_text_View

// header file dependencies
// @dep_header javax_swing_text_View

#include "javax/swing/text/View.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24RootView_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24RootView_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTextUI$object;
struct _jc_javax_swing_text_Position__24Bias$object;
struct _jc_javax_swing_text_View$object;
struct _jc_javax_swing_text_ViewFactory$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$_init$7d9c801be3d1d113(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_javax_swing_plaf_basic_BasicTextUI$object *);

// Virtual methods
extern struct _jc_java_awt_Container$object *_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$getContainer$b41eecd3d62ddbe0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *);
extern jfloat _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$getPreferredSpan$8d3c9b3b44df365e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$getViewFactory$7b0683a833033cb8(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$modelToView$58cd7cb44b36f158(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *);
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$paint$4a5b2b5c3e62fdfc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *);
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$setView$af665dbb04a8fab5(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_javax_swing_text_View$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$getContainer$b41eecd3d62ddbe0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$getPreferredSpan$8d3c9b3b44df365e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$getViewFactory$7b0683a833033cb8;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$modelToView$58cd7cb44b36f158;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$paint$4a5b2b5c3e62fdfc;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$setView$af665dbb04a8fab5;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods {
	struct _jc_java_awt_Container$object	*(*getContainer$b41eecd3d62ddbe0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *);
	jfloat	(*getPreferredSpan$8d3c9b3b44df365e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint);
	struct _jc_object	*(*getViewFactory$7b0683a833033cb8)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *);
	struct _jc_object	*(*modelToView$58cd7cb44b36f158)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *);
	void	(*paint$4a5b2b5c3e62fdfc)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *);
	void	(*setView$af665dbb04a8fab5)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_javax_swing_text_View$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_View$vmethods	javax_swing_text_View;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods	javax_swing_plaf_basic_BasicTextUI__24RootView;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs {
	struct _jc_javax_swing_text_View$object	*view;
	struct _jc_javax_swing_plaf_basic_BasicTextUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs	javax_swing_plaf_basic_BasicTextUI__24RootView;
    _jc_javax_swing_text_View$sub_refs	javax_swing_text_View;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_View$sub_nonrefs	javax_swing_text_View;
    _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24RootView;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24RootView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24RootView_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTextUI__24RootView.h <==
// class javax.swing.plaf.basic.BasicTextUI$RootView

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3c149a3a98797f6b javax_swing_plaf_basic_BasicTextUI__24RootView
// @dep_class b564f56d2f2041c1 javax_swing_text_View

// header file dependencies
// @dep_header javax_swing_text_View

#include "javax/swing/text/View.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24RootView_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24RootView_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTextUI$object;
struct _jc_javax_swing_text_Position__24Bias$object;
struct _jc_javax_swing_text_View$object;
struct _jc_javax_swing_text_ViewFactory$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$_init$7d9c801be3d1d113(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_javax_swing_plaf_basic_BasicTextUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Container$object *_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$getContainer$b41eecd3d62ddbe0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *) _JC_JCNI_ATTR;
extern jfloat _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$getPreferredSpan$8d3c9b3b44df365e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$getViewFactory$7b0683a833033cb8(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$modelToView$58cd7cb44b36f158(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$paint$4a5b2b5c3e62fdfc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method$setView$af665dbb04a8fab5(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$getContainer$b41eecd3d62ddbe0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$getPreferredSpan$8d3c9b3b44df365e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$getViewFactory$7b0683a833033cb8;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$modelToView$58cd7cb44b36f158;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$paint$4a5b2b5c3e62fdfc;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$method_info$setView$af665dbb04a8fab5;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods {
	struct _jc_java_awt_Container$object	*(*getContainer$b41eecd3d62ddbe0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *) _JC_JCNI_ATTR;
	jfloat	(*getPreferredSpan$8d3c9b3b44df365e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*getViewFactory$7b0683a833033cb8)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*modelToView$58cd7cb44b36f158)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
	void	(*paint$4a5b2b5c3e62fdfc)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setView$af665dbb04a8fab5)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_View$vmethods	javax_swing_text_View;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vmethods	javax_swing_plaf_basic_BasicTextUI__24RootView;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs {
	struct _jc_javax_swing_text_View$object	*view;
	struct _jc_javax_swing_plaf_basic_BasicTextUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_refs	javax_swing_plaf_basic_BasicTextUI__24RootView;
    _jc_javax_swing_text_View$sub_refs	javax_swing_text_View;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_View$sub_nonrefs	javax_swing_text_View;
    _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24RootView;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24RootView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24RootView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24RootView$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24RootView_H_ */
